/*
 * Copyright (c) 1995 by CompuServe Incorporated, Columbus, Ohio
 *
 * Facility:  None
 *
 * Abstract:
 *
 *     This header file contains #defines for the error return values, and
 *     and other return values of POSIX system calls.  The intention is to
 *     allow for the replacement of confusing numeric constants with meaningful
 *     names.
 *
 * Environment:  BSDI's BSD/OS 1.1 (POSIX)
 *
 * Author:  William L. Chatfield (BCHATFIELD), 13-Jul-95
 *
 * Revision History:
 *
 * 1.0  William L. Chatfield (BCHATFIELD), 13-Jul-95
 *      - Initial revision
 */

#ifndef POSERR_H
#define POSERR_H

/*
 * External Interfaces
 */

/*
 * Constants, structures, and typedefs
 */
#define SETEUID_ERROR         -1
#define CHDIR_ERROR           -1
#define SETRLIMIT_ERROR       -1
#define GETRLIMIT_ERROR       -1
#define OPEN_ERROR            -1
#define ATEXIT_ERROR          -1
#define RAISE_ERROR           -1
#define FCNTL_ERROR           -1
#define READ_ERROR            -1
#define WRITE_ERROR           -1
#define SEND_ERROR            -1
#define SENDTO_ERROR          -1
#define RECV_ERROR_OR_NO_DATA -1
#define RECVFROM_ERROR        -1
#define SELECT_ERROR          -1
#define SOCKET_ERROR          -1
#define CONNECT_ERROR         -1
#define TIME_ERROR            -1
#define PCLOSE_ERROR          -1
#define SIGACTION_ERROR       -1
#define GETHOSTNAME_ERROR     -1
#define GETPEERNAME_ERROR     -1
#define SETSOCKOPT_ERROR      -1
#define FORK_ERROR            -1
#define WAIT_ERROR            -1
#define DUP2_ERROR            -1
#define EXECL_ERROR           -1
#define CLOSE_ERROR           -1
#define BIND_ERROR            -1
#define ACCEPT_ERROR          -1
#define LISTEN_ERROR          -1
#define STAT_ERROR            -1
#define IOCTL_ERROR           -1

#define EMPTY_SOCKET_FLAGS     0
#define READ_EOF               0
#define SELECT_TIMEOUT         0
#define FORK_CHILD_PROCESS     0

#define FWRITE_ERROR           0

#define GETPWNAM_ERROR        ((struct passwd *) 0)
#define GETPWUID_ERROR        ((struct passwd *) 0)

#define GETSERVBYNAME_ERROR   ((struct servent *) NULL)
#define GETHOSTBYNAME_ERROR   ((struct hostent *) NULL)
#define GETHOSTBYADDR_ERROR   ((struct hostent *) NULL)
#define GETCWD_ERROR          ((char *) NULL)

#if 0
/*
 * Possibly a superior implementation.  x is the return value from the
 * associated function.
 */
#define SIGACTION_ERROR(x) (x == -1)
#define SIGACTION_OK(x)    (x == 0)

#define READ_ERROR(x)      (x == -1)
#define READ_EOF(x)        (x == 0)
#define READ_OK(x)         (x > 0)   /* this is not possible the other way */
#endif

/*
 * External data
 */

/*
 * Function prototypes
 */

#endif
