/*
 * inetcis.adm.c
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <netdb.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <command.h>
#include <misc.h>
#include <log.h>

#define MAXSTRLEN 255

void Get_Server_Name (char *server_name);
int Get_Server_Address (char *server_name,struct sockaddr_in *server_address);
void Main_Menu (int cmd_sock_fd, char *server_name,
		struct sockaddr_in *server_address);

int
main (int argc, char **argv)
{
  char server_name[MAXSTRLEN+1];
  struct sockaddr_in server_address;
  int cmd_sock_fd;

  Start_Inhouse_Stderr_Log ("GWA");
  if (Create_Client_Command_Socket (&cmd_sock_fd)) {
    if (Get_Server_Address (server_name, &server_address))
      Main_Menu (cmd_sock_fd, server_name, &server_address);
  }
  Close_Log ();
  return 1;
}

void Get_Server_Name (char *server_name)
{
  printf ("Enter gateway name: ");
  fgets (server_name, MAXSTRLEN+1, stdin);
  server_name[strlen(server_name) - 1] = 0;
}

int Get_Server_Address (char *server_name, struct sockaddr_in *server_address)
{
  struct hostent *server_hostent;
  struct in_addr **dns_list;
  extern int h_errno;

  bzero (server_address, sizeof(struct sockaddr_in));
  server_address->sin_family = AF_INET;
  server_address->sin_port = Convert_Service_To_Port (COMMAND_PORT_NAME);
  if (server_address->sin_port == FAILURE)
    return FAILURE;

  while (1) {
    Get_Server_Name (server_name);
    if (isalpha(server_name[0]))
      /* convert character name to struct hostent */
      server_hostent = gethostbyname (server_name);
    else {
      /* convert dotted decimal to a struct hostent */
      struct in_addr server_in_addr;
      inet_aton (server_name, &server_in_addr);
      server_hostent = gethostbyaddr ((char *) &server_in_addr,
				      (int) sizeof (server_in_addr),
				      AF_INET);
    }

    /* Check for error in either gethostbyname or gethostbyaddr. */
    if (server_hostent == NULL) {
      char h_errno_text[MAXSTRLEN+1];
      Convert_h_errno_To_Text (h_errno, h_errno_text);
      Write_Error_To_Log (LOG_LEVEL_WARNING, __FILE__, __LINE__, server_name,
			 "gethostbyname/addr", "ADR", h_errno_text);
      continue;
    }
    
    /* make sure there is only one address in the list */
    dns_list = (struct in_addr **) server_hostent->h_addr_list;
    if (dns_list[1] == 0)
      break;  /* we've got a good address so lets exit the loop */
    else
      Write_Error_To_Log (LOG_LEVEL_WARNING, __FILE__, __LINE__, server_name,
			  "gethostbyname/addr", "AML",
			  "Name resolves to multiple hosts");
  }

  server_address->sin_addr = *(dns_list[0]);
  return SUCCESS;
}

void Main_Menu (int cmd_sock_fd, char *server_name,
		struct sockaddr_in *server_address)
{
  char choice[MAXSTRLEN+1];
  int done = 0;
  CommandStatusType command_status;

  do {
    printf ("\nGateway Administration Tool Menu\n");
    printf ("gateway: %s\n", server_name);
    printf ("0. Change Current Gateway\n");
    printf ("1. Stop Accepting Connections\n");
    printf ("2. Start Accepting Connections\n");
    printf ("3. Exit\n");
    printf ("Enter choice: ");
    fgets (choice, MAXSTRLEN+1, stdin);

    if (strlen(choice) > 2)
      continue;

    switch (choice[0]) {
    case '0':
      Get_Server_Address (server_name, server_address);
      break;
    case '1':
      command_status =
	Send_Simple_Command (cmd_sock_fd, server_address,
			     COMMAND_STOP_ACCEPTING_CONNECTIONS);
      break;
    case '2':
      command_status =
	Send_Simple_Command (cmd_sock_fd, server_address,
			     COMMAND_START_ACCEPTING_CONNECTIONS);
      break;
    case '3':
      done = 1;
      break;
    default:
      printf ("Hey dickhead!  Do it right!\n");
    }
  } while (! done);
}
